@@ -21,7 +21,8 @@ import random
 import sys
 import traceback
 
-import gtk, gobject
+import gtk
+import gobject
 
 from solfege import gu
 from solfege import inputwidgets
@@ -273,14 +274,14 @@ class RhythmAddOnClass:
         Return a complete mpd string of the current question that can
         be feed to utils.play_music.
         """
-        return r"\staff{%s}" % self.get_music_notenames(True)
+        return r"\rhythmstaff{%s}" % self.get_music_notenames(True)
     def play_rhythm(self, rhythm):
         """
         rhythm is a string. Example: 'c4 c8 c8 c4'
         """
         # FIXME can we use lessonfile.Rhythm insted of this?
         score = mpd.parser.parse_to_score_object(rhythm)
-        track = mpd.score_to_percussion_tracks(score)[0]
+        track = mpd.score_to_tracks(score)[0]
         track.prepend_bpm(self.get_int("bpm"))
         track.prepend_volume(cfg.get_int('config/preferred_instrument_volume'))
         track.replace_note(mpd.notename_to_int("c"),
@@ -559,10 +560,10 @@ class Gui(gtk.VBox, cfg.ConfigUtils, QstatusDefs):
         try:
             if self.m_t.m_custom_mode:
                 self.g_statview.set_sensitive(False)
-                self.g_statview.set_tooltip_text(_("Statistics is disabled. Either because you selected a “Configure yourself” exercise, or because “Expert mode” is selected in the preferences window."))
+                self.g_statview.set_tooltip_text(_(u"Statistics is disabled. Either because you selected a “Configure yourself” exercise, or because “Expert mode” is selected in the preferences window."))
             else:
                 self.g_statview.set_sensitive(True)
-                self.g_statview.set_tooltip_text(None)
+                self.g_statview.set_tooltip_text("")
         except AttributeError: # not all exercises has g_statview
             pass
     def on_key_press_event(self, widget, event):
